"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Progress = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var rc_progress_1 = require("rc-progress");
var theme_1 = require("../theme");
var Progress = /** @class */ (function (_super) {
    (0, tslib_1.__extends)(Progress, _super);
    function Progress() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Progress.prototype.autoClassName = function (value) {
        var map = this.props.map;
        if (!map || !map.length) {
            return '';
        }
        var index = Math.floor((value * map.length) / 100);
        index = Math.max(0, Math.min(map.length - 1, index));
        return map[index];
    };
    Progress.prototype.getLabel = function (prefixCls) {
        var _a = this.props, value = _a.value, format = _a.format, showLabel = _a.showLabel, cx = _a.classnames;
        if (!showLabel) {
            return null;
        }
        var textFormatter = format || (function (value) { return "".concat(value, "%"); });
        var content = textFormatter(value);
        return (react_1.default.createElement("span", { className: cx("".concat(prefixCls, "-text")), key: "value" }, content));
    };
    Progress.prototype.render = function () {
        var _a, _b, _c;
        var _d = this.props, classNames = _d.classNames, progressClassName = _d.progressClassName, progressBarClassName = _d.progressBarClassName, type = _d.type, value = _d.value, placeholder = _d.placeholder, stripe = _d.stripe, animate = _d.animate, showLabel = _d.showLabel, gapDegree = _d.gapDegree, gapPosition = _d.gapPosition, strokeWidth = _d.strokeWidth, cx = _d.classnames;
        var isLineType = type === 'line';
        var prefixCls = isLineType ? 'Progress-line' : 'Progress-circle';
        var viewValue;
        if (typeof value !== 'number') {
            viewValue = react_1.default.createElement("span", { className: "text-muted" }, placeholder);
        }
        else if (type === 'line') {
            var style = {};
            strokeWidth && (style.height = strokeWidth);
            viewValue = [
                react_1.default.createElement("div", { key: "progress", className: cx(prefixCls, progressClassName) },
                    react_1.default.createElement("div", { className: cx("".concat(prefixCls, "-inter")), style: style },
                        react_1.default.createElement("div", { className: cx("".concat(prefixCls, "-bar"), progressBarClassName || this.autoClassName(value), (_a = {}, _a["".concat(prefixCls, "-bar--stripe")] = stripe, _a), (_b = {}, _b["".concat(prefixCls, "-bar--animate")] = animate && !stripe, _b), (_c = {}, _c["".concat(prefixCls, "-bar--stripe-animate")] = animate && stripe, _c)), title: "".concat(value, "%"), style: {
                                width: "".concat(value, "%")
                            } }))),
                this.getLabel(prefixCls)
            ];
        }
        else if (type === 'circle' || type === 'dashboard') {
            var circleWidth = strokeWidth || 6;
            var gapPos = gapPosition || (type === 'dashboard' && 'bottom') || 'top';
            var getGapDegree = function () {
                if (gapDegree || gapDegree === 0) {
                    return gapDegree;
                }
                if (type === 'dashboard') {
                    return 75;
                }
                return undefined;
            };
            viewValue = [
                react_1.default.createElement("div", { className: cx(prefixCls), key: "circle" },
                    react_1.default.createElement(rc_progress_1.Circle, { percent: value, strokeColor: "", strokeWidth: circleWidth, trailWidth: circleWidth, prefixCls: this.autoClassName(value), gapDegree: getGapDegree(), gapPosition: gapPos }),
                    this.getLabel(prefixCls))
            ];
        }
        return react_1.default.createElement("div", { className: cx('Progress', classNames) }, viewValue);
    };
    Progress.defaultProps = {
        type: 'line',
        placeholder: '-',
        progressClassName: '',
        progressBarClassName: '',
        map: ['bg-danger', 'bg-warning', 'bg-info', 'bg-success', 'bg-success'],
        showLabel: true
    };
    return Progress;
}(react_1.default.Component));
exports.Progress = Progress;
exports.default = (0, theme_1.themeable)(Progress);
//# sourceMappingURL=./components/Progress.js.map
