import React from 'react';
import { RendererProps } from '../factory';
import { BaseSchema, SchemaCollection } from '../Schema';
import type { Trigger } from '../components/TooltipWrapper';
export interface TooltipWrapperSchema extends BaseSchema {
    /**
     * 文字提示容器
     */
    type: 'tooltip-wrapper';
    /**
     * 文字提示标题
     */
    title?: string;
    /**
     * 文字提示
     */
    tooltip?: string;
    /**
     * 文字提示浮层出现位置，默认为top
     */
    placement?: 'top' | 'right' | 'bottom' | 'left';
    /**
     * 浮层触发方式，默认为hover
     */
    trigger?: Trigger | Array<Trigger>;
    /**
     * 浮层隐藏延迟时间，单位ms，默认0
     */
    delay?: number;
    /**
     * 是否点击非内容区域关闭提示，默认为true
     */
    rootClose?: boolean;
    /**
     * 内容区域
     */
    body?: SchemaCollection;
    /**
     * 内容区包裹标签
     */
    wrapperComponent: string;
    /**
     * 内容区是否内联显示，默认为false
     */
    inline?: boolean;
    /**
     * 浮层主题色，默认为light
     */
    tooltipTheme?: 'light' | 'dark';
    /**
     * 内容区自定义样式
     */
    style?: {
        [propName: string]: any;
    };
    /**
     * 自定义提示浮层样式
     */
    tooltipStyle?: {
        [propName: string]: any;
    };
    /**
     * 内容区CSS类名
     */
    className?: string;
    /**
     * 文字提示浮层CSS类名
     */
    tooltipClassName?: string;
}
export interface TooltipWrapperProps extends RendererProps {
    /**
     * 文字提示标题
     */
    title?: string;
    /**
     * 文字提示
     */
    tooltip?: string;
    /**
     * 文字提示位置
     */
    placement: 'top' | 'right' | 'bottom' | 'left';
    inline?: boolean;
    trigger: Trigger | Array<Trigger>;
    rootClose?: boolean;
    delay?: number;
    container?: React.ReactNode;
    style?: React.CSSProperties;
    tooltipStyle?: React.CSSProperties;
    wrapperComponent?: string;
    tooltipTheme?: 'light' | 'dark';
}
interface TooltipWrapperState {
}
export default class TooltipWrapper extends React.Component<TooltipWrapperProps, TooltipWrapperState> {
    static defaultProps: Pick<TooltipWrapperProps, 'placement' | 'trigger' | 'rootClose' | 'delay' | 'inline' | 'wrap' | 'tooltipTheme'>;
    constructor(props: TooltipWrapperProps);
    renderBody(): JSX.Element;
    render(): JSX.Element;
}
export declare class TooltipWrapperRenderer extends TooltipWrapper {
}
export {};
